@@ -11,7 +11,7 @@ use Coro::Channel;
 use Coro::ProcessPool::Process;
 use Coro::ProcessPool::Util qw(cpu_count);
 
-our $VERSION = '0.14_01';
+our $VERSION = '0.15_01';
 
 if ($^O eq 'MSWin32') {
     die 'MSWin32 is not supported';
@@ -216,11 +216,11 @@ packages used by client code.
 
 Processes code ref C<$f> in a child process from the pool. If C<$args> is
 provided, it is an array ref of arguments that will be passed to C<$f>. Returns
-the result of calling C<$f->(@$args)>.
+the result of calling $f->(@$args).
 
 Alternately, C<$f> may be the name of a class implementing the methods C<new>
 and C<run>, in which case the result is equivalent to calling
-C<$f->new(@$args)->run()>. Note that the include path for worker processes is
+$f->new(@$args)->run(). Note that the include path for worker processes is
 identical to that of the calling process.
 
 This call will yield until the results become available. If all processes are
